@@ -19,7 +19,7 @@ class CountingPyro4Migration(Pyro4Migration):
     def migrate(self, agent):
         if super(CountingPyro4Migration, self).migrate(agent):
             CountingPyro4Migration.counter += 1
-            logging.info("migrated!")
+          #  logging.info("migrated!")
 
 
 
